//---------------------------------------------------------------------------------------------------
// http://www.f-lohmueller.de/pov_tut/addon/00_Basic_Templates/49_meshmaker_inc/__index.htm
// http://www.f-lohmueller.de/pov_tut/addon/00_Basic_Templates/49_meshmaker_inc/60_p_square_uv.txt
// see also:  http://news.povray.org/povray.general/thread/%3C5eafeab9%241%40news.povray.org%3E/
//---------------------------------------------------------------------------------------------------

//---------------------------------------------------------------------------------------------------
#include "meshmaker.inc"
//---------------------------------------------------------------------------------------------------
/*
//The following code from the Lohmueller site...

//function format:
#declare F1= function(u,v){u} 
#declare F2= function(u,v){v} 
#declare F3= function(u,v){0}

//example functions:
#declare D=0.5;   //depth
#declare FR=function{pattern{bozo scale 0.65}}
#declare F1=function(u,v){(-(FR(u,v,0)*D)+u)}
#declare F2=function(u,v){(-(FR(u,v,0)*D)+v)}
#declare F3=function(u,v){(-(FR(u,v,0)*D)+0)}

//and the conversion:
object{ //-------------------------------------------------------------------------------------------
   Parametric( //(Fx,Fy, Fz, <UVmin>, <UVmax>, Iter_U, Iter_V, FileName)
               // Builds a parametric surface out of three given functions. 
               // The uv_coordinates for texturing the surface come from the square <0,0> - <1,1>. 
      F1, F2, F3, //three functions from which the object will be generated. 
        // Following 2 vectors are the range within which the surface is calculated: 
      <-1.85,-1.65>, // 2-D vector that gives the lower boundaries of the uv-rectangle, <u min, v min>. 
      < 1.85, 1.65>, // 2-D vector that gives the upper boundaries of the uv-rectangle. 
      50, // 
      50, //
       ""  // FileName: ""= non, "NAME.obj'= Wavefront objectfile, "NAME.pcm" compressed mesh file 
           // "NAME.arr" = include file with arrays to build a mesh2 from, 
           //  others: includefile with a mesh2 object 
   ) //----------------------------------------------------------------------------------------------
   interior_texture {  //  outside texture
     uv_mapping
     pigment {checker color rgb <0.0,0,0.0> rgb <1,0.9,0.9> scale <0.025,0.025,1>}
     finish{specular 0.5}
   } // 
   texture{            // inside texture
     uv_mapping
     pigment {checker color rgb <0.0,0.2,0.5> rgb <1,1,1> scale <0.025,0.025,1>}
     finish{specular 0.5}
   } // 
   //rotate <180, 0, 0>
   //scale<2,1,2>
   //translate< 0,1,0>
} // end of object 
*/

//===================================================================================================
//... is replaced by the different parametric grassblade parameters, as provided by LMgrassblades.inc:

//parametric functions (here for Blunt3):
#declare kruemmung = 1.0;
#declare F4        = function(u,v){u} 
#declare F5        = function(u,v){ 1-(u-1)*(u-1) } 
#declare F6        = function(u,v){ v*(2*kruemmung-u)/kruemmung }

//the following builds a parametric surface out of the Curvature (kruemmung) parameter and the three  
//given functions, and converts it to the appropriate format. The uv_coordinates for texturing the 
//surface come from the square <0,0> - <1,1>. 

//Parametric (Fx,Fy, Fz, <UVmin>, <UVmax>, Iter_U, Iter_V, FileName)
object {
  Parametric(
      F4, F5, F6,        // the three functions from which the object will be generated. 
                         // the following 2 vectors are the range within which the surface is calculated: 
      <0, -0.03>,        // 2-D vector that gives the lower boundaries of the uv-rectangle, <u min, v min>. 
      <kruemmung, 0.03>, // 2-D vector that gives the upper boundaries of the uv-rectangle. 
      50,                // number of iterations in the u direction.
      50,                // number of iterations in the v direction.
      "00_Blunt3.inc"    // fileName: ""= no name; "NAME.obj'= Wavefront objectfile; "NAME.pcm"= compressed mesh file; 
                         // "NAME.arr"= include file with arrays to build a mesh2 from; 
                         // others: mesh2{} object include file. 
  )
  // the following textures will not appear in the conversion. Add later the grassblade finish and normals.
  // Beware: the pigments themselves are defined separately in lawnmaker.inc!
  /*interior_texture {     // outside texture
    uv_mapping
    pigment {checker color rgb <0.0,0,0.0> rgb <1,0.9,0.9> scale <0.025,0.025,1>}
    finish{specular 0.5}
  } 
  texture {              // inside texture
    uv_mapping
    pigment {checker color rgb <0.0,0.2,0.5> rgb <1,1,1> scale <0.025,0.025,1>}
    finish{specular 0.5}
  }*/
  //rotate <180, 0, 0>  // do not use here
  //scale <2, 1, 2>     // do not use here
  //translate <0, 1, 0> // do not use here
  
} // end of object 

//===================================================================================================
/*
camera { 
  location  <0, 10, -20> 
  direction 1.5*z
  right x*image_width/image_height  
  look_at   <0.0, 0.0,  0.0>
}

light_source {
  <-30, 30, -30>            
  color rgb <1, 1, 1>  
}
*/
